## dbt-tests-adapter 1.19.0 - September 29, 2025

### Features

- Add test for scenario where soure/target relations are the same ([#1198](https://github.com/dbt-labs/dbt-adapters/issues/1198))
- Add BaseSnapshotEphemeralHardDeletes test  ([#1201](https://github.com/dbt-labs/dbt-adapters/issues/1201))

### Fixes

- Fix duplicates when hard_deletes new_record is used with custom dbt_valid_to_current ([#1240](https://github.com/dbt-labs/dbt-adapters/issues/1240))

### Under the Hood

- Improve test coverage for snapshots with new record mode ([#654](https://github.com/dbt-labs/dbt-adapters/issues/654))

### Contributors
- [@jeremyyeo](https://github.com/jeremyyeo) ([#1240](https://github.com/dbt-labs/dbt-adapters/issues/1240))
- [@lpillmann](https://github.com/lpillmann) ([#654](https://github.com/dbt-labs/dbt-adapters/issues/654))
